Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(278)

Unified Diff: components/autofill/core/browser/autofill_driver.h

Issue 18693005: Move AutofillMsg_ClearPreviewedForm IPC send to AutofillDriverImpl (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Response to review Created 7 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/autofill/core/browser/autofill_driver.h
diff --git a/components/autofill/core/browser/autofill_driver.h b/components/autofill/core/browser/autofill_driver.h
index 02ae8cfd5eb109ab71aa3f04589120e8c086911a..2c1e175ee35c55b422f67d3c576cfd9bb41fd095 100644
--- a/components/autofill/core/browser/autofill_driver.h
+++ b/components/autofill/core/browser/autofill_driver.h
@@ -55,8 +55,11 @@ class AutofillDriver {
virtual void SendAutofillTypePredictionsToRenderer(
const std::vector<FormStructure*>& forms) = 0;
- // Tells the renderer to clear the currently displayed Autofill results.
- virtual void RendererShouldClearForm() = 0;
+ // Tells the renderer to clear the currently filled Autofill results.
+ virtual void RendererShouldClearFilledForm() = 0;
+
+ // Tells the renderer to clear the currently previewed Autofill results.
+ virtual void RendererShouldClearPreviewedForm() = 0;
};
} // namespace autofill

Powered by Google App Engine
This is Rietveld 408576698